# StreamSQL

![](https://github.com/streamsql-io/streamsql/workflows/Client%20Unit%20Tests/badge.svg?branch=develop)
[![codecov-develop](https://codecov.io/gh/streamsql-io/streamsql/branch/develop/graph/badge.svg)](https://codecov.io/gh/streamsql-io/streamsql)

StreamSQL provides centeralized registry of machine learning features and offers a unified interface to serve online features and generate training datasets.
